"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createSimpleContext = exports.SimpleContext = void 0;
const crypto_1 = require("crypto");
const async_hooks_1 = __importDefault(require("async_hooks"));
class SimpleContext {
    constructor(id = (0, crypto_1.randomUUID)()) {
        this.id = id;
        this.properties = {};
        this.forks = [];
        this.contextId = this.id;
    }
    getProperty(key) {
        return this.properties[key];
    }
    setProperty(key, value) {
        this.properties[key] = value;
    }
    fork() {
        const id = async_hooks_1.default.executionAsyncId().toString();
        this.forks = [...this.forks, new SimpleContext(id)];
    }
    setForkProperty(key, value) {
        const id = async_hooks_1.default.executionAsyncId().toString();
        const fork = this.forks.find((fork) => fork.contextId === id);
        if (fork) {
            fork.setProperty(key, value);
        }
    }
    getForkProperty(key) {
        const id = async_hooks_1.default.executionAsyncId().toString();
        const fork = this.forks.find((fork) => fork.contextId === id);
        if (fork) {
            return fork.getProperty(key);
        }
        return undefined;
    }
}
exports.SimpleContext = SimpleContext;
function createSimpleContext() {
    return new SimpleContext();
}
exports.createSimpleContext = createSimpleContext;
